@@ -49,13 +49,12 @@ class ExportDialog(QtWidgets.QWidget):
         self.activateWindow()
         self.raise_()
         self.selectBox.setVisible(True)
-        
         if not self.shown:
             self.shown = True
-            vcenter = self.scene.getViewWidget().geometry().center()
-            self.setGeometry(int(vcenter.x() - self.width() / 2),
-                             int(vcenter.y() - self.height() / 2),
-                             self.width(), self.height())
+            center = self.screen().availableGeometry().center()
+            frame = self.frameGeometry()
+            frame.moveCenter(center)
+            self.move(frame.topLeft())
         
     def updateItemList(self, select=None):
         self.ui.itemTree.clear()
@@ -86,6 +85,7 @@ class ExportDialog(QtWidgets.QWidget):
             self.updateItemTree(ch, treeItem, select=select)
         
             
+    @QtCore.Slot(QtWidgets.QTreeWidgetItem, QtWidgets.QTreeWidgetItem)
     def exportItemChanged(self, item, prev):
         if item is None:
             return
@@ -105,13 +105,14 @@ class ExportDialog(QtWidgets.QWidget):
         for exp in exporters.listExporters():
             item = FormatExportListWidgetItem(exp, QtCore.QCoreApplication.translate('Exporter', exp.Name))
             self.ui.formatList.addItem(item)
-            if item == current:
+            if item is current:
                 self.ui.formatList.setCurrentRow(self.ui.formatList.count() - 1)
                 gotCurrent = True
                 
         if not gotCurrent:
             self.ui.formatList.setCurrentRow(0)
         
+    @QtCore.Slot(QtWidgets.QListWidgetItem, QtWidgets.QListWidgetItem)
     def exportFormatChanged(self, item, prev):
         if item is None:
             self.currentExporter = None
@@ -129,10 +130,12 @@ class ExportDialog(QtWidgets.QWidget):
         self.currentExporter = exp
         self.ui.copyBtn.setEnabled(exp.allowCopy)
         
+    @QtCore.Slot()
     def exportClicked(self):
         self.selectBox.hide()
         self.currentExporter.export()
         
+    @QtCore.Slot()
     def copyClicked(self):
         self.selectBox.hide()
         self.currentExporter.export(copy=True)
