@@ -1,5 +1,6 @@
 import ctypes
 import itertools
+import sys
 
 import numpy as np
 
@@ -9,75 +10,77 @@ __all__ = ["get_qpainterpath_element_array"]
 
 if QT_LIB.startswith('PyQt'):
     from . import sip
+    qt_version_info = tuple((QtCore.QT_VERSION >> i) & 0xff for i in [16,8,0])
 elif QT_LIB == 'PySide2':
     from PySide2 import __version_info__ as pyside_version_info
+    qt_version_info = QtCore.__version_info__
 elif QT_LIB == 'PySide6':
     from PySide6 import __version_info__ as pyside_version_info
+    qt_version_info = QtCore.__version_info__
 
-class QArrayDataQt5(ctypes.Structure):
-    _fields_ = [
+
+class Element(ctypes.Structure):
+    _fields_=  [('x', ctypes.c_double), ('y', ctypes.c_double), ('c', ctypes.c_int)]
+
+class QArrayData(ctypes.Structure):
+    pass
+
+class QPainterPathPrivate(ctypes.Structure):
+    pass
+
+if qt_version_info[0] == 5:
+    QArrayData._fields_ = [
         ("ref", ctypes.c_int),
         ("size", ctypes.c_int),
         ("alloc", ctypes.c_uint, 31),
         ("offset", ctypes.c_ssize_t),
     ]
 
-class QPainterPathPrivateQt5(ctypes.Structure):
-    _fields_ = [
+    QPainterPathPrivate._fields_ = [
         ("ref", ctypes.c_int),
-        ("adata", ctypes.POINTER(QArrayDataQt5)),
+        ("adata", ctypes.POINTER(QArrayData)),
     ]
 
-class QArrayDataQt6(ctypes.Structure):
-    _fields_ = [
+elif qt_version_info[0] == 6:
+    QArrayData._fields_ = [
         ("ref", ctypes.c_int),
         ("flags", ctypes.c_uint),
         ("alloc", ctypes.c_ssize_t),
     ]
 
-class QPainterPathPrivateQt6(ctypes.Structure):
-    _fields_ = [
+    QPainterPathPrivate._fields_ = [
         ("ref", ctypes.c_int),
-        ("adata", ctypes.POINTER(QArrayDataQt6)),
+        ("adata", ctypes.POINTER(QArrayData)),
         ("data", ctypes.c_void_p),
         ("size", ctypes.c_ssize_t),
-    ]
+    ][int(qt_version_info >= (6, 10)):]
 
 def get_qpainterpath_element_array(qpath, nelems=None):
-    writable = nelems is not None
-    if writable:
+    resize = nelems is not None
+    if resize:
         qpath.reserve(nelems)
 
-    itemsize = 24
-    dtype = dict(names=['x','y','c'], formats=['f8', 'f8', 'i4'], itemsize=itemsize)
+    ptr = ctypes.c_void_p.from_address(compat.unwrapinstance(qpath))
+    if not ptr:
+        return np.zeros(0, dtype=Element)
 
-    ptr0 = compat.unwrapinstance(qpath)
-    pte_cp = ctypes.c_void_p.from_address(ptr0)
-    if not pte_cp:
-        return np.zeros(0, dtype=dtype)
+    ppp = ctypes.cast(ptr, ctypes.POINTER(QPainterPathPrivate)).contents
 
-    # _cp : ctypes pointer
-    # _ci : ctypes instance
-    if QT_LIB in ['PyQt5', 'PySide2']:
-        PTR = ctypes.POINTER(QPainterPathPrivateQt5)
-        pte_ci = ctypes.cast(pte_cp, PTR).contents
-        size_ci = pte_ci.adata[0]
-        eptr = ctypes.addressof(size_ci) + size_ci.offset
-    elif QT_LIB in ['PyQt6', 'PySide6']:
-        PTR = ctypes.POINTER(QPainterPathPrivateQt6)
-        pte_ci = ctypes.cast(pte_cp, PTR).contents
-        size_ci = pte_ci
-        eptr = pte_ci.data
+    if qt_version_info[0] == 5:
+        qad = ppp.adata.contents
+        eptr = ctypes.addressof(qad) + qad.offset
+        if resize:
+            qad.size = nelems
+    elif qt_version_info[0] == 6:
+        eptr = ppp.data
+        if resize:
+            ppp.size = nelems
     else:
         raise NotImplementedError
 
-    if writable:
-        size_ci.size = nelems
-    else:
-        nelems = size_ci.size
-
-    vp = compat.voidptr(eptr, itemsize*nelems, writable)
-    return np.frombuffer(vp, dtype=dtype)
+    nelems = qpath.elementCount()
+    buf = (Element * nelems).from_address(eptr)
+    return np.frombuffer(buf, dtype=Element)
 
 class PrimitiveArray:
     # Note: This class is an internal implementation detail and is not part
@@ -175,17 +178,10 @@ class PrimitiveArray:
     def ndarray(self):
         # ndarray views are cheap to recreate each time
         if self.use_sip_array:
-            if (
-                sip.SIP_VERSION >= 0x60708 and 
-                np.__version__ != "1.22.4"  # TODO: remove me after numpy 1.23+
-            ):  # workaround for numpy/sip compatability issue
-                # see https://github.com/numpy/numpy/issues/21612
-                mv = self._siparray
-            else:
-                # sip.array prior to SIP_VERSION 6.7.8 had a buggy buffer protocol
-                # that set the wrong size.
-                # workaround it by going through a sip.voidptr
-                mv = sip.voidptr(self._siparray, self._capa*self._nfields*8)
+            # sip.array prior to SIP_VERSION 6.7.8 had a buggy buffer protocol
+            # that set the wrong size.
+            # workaround it by going through a sip.voidptr
+            mv = sip.voidptr(self._siparray, self._capa*self._nfields*8)
             # note that we perform the slicing by using only _size rows
             nd = np.frombuffer(mv, dtype=np.float64, count=self._size*self._nfields)
             return nd.reshape((-1, self._nfields))
@@ -229,3 +225,28 @@ class PrimitiveArray:
 
         else:
             return self.instances(),
+
+
+_qbytearray_leaks = None
+
+def qbytearray_leaks() -> bool:
+    global _qbytearray_leaks
+
+    if _qbytearray_leaks is None:
+        # When PySide{2,6} is built without Py_LIMITED_API,
+        # it leaks memory when a memory view to a QByteArray
+        # object is taken.
+        # See https://github.com/pyqtgraph/pyqtgraph/issues/3265
+        # and PYSIDE-3031
+        # Note: official builds of PySide{2,6} by Qt are built with
+        # the limited api, and thus do not leak.
+        if QT_LIB.startswith("PySide"):
+            # probe whether QByteArray leaks
+            qba = QtCore.QByteArray()
+            ref0 = sys.getrefcount(qba)
+            memoryview(qba)
+            _qbytearray_leaks = sys.getrefcount(qba) > ref0
+        else:
+            _qbytearray_leaks = False
+
+    return _qbytearray_leaks
