@@ -3,7 +3,7 @@ PyQtGraph - Scientific Graphics and GUI Library for Python
 www.pyqtgraph.org
 """
 
-__version__ = '0.13.4'
+__version__ = '0.14.0'
 
 ### import all the goodies and add some helper functions for easy CLI use
 
@@ -27,18 +27,8 @@ from .Qt import mkQApp
               ## (import here to avoid massive error dump later on if numpy is not available)
 
 
-## in general openGL is poorly supported with Qt+GraphicsView.
-## we only enable it where the performance benefit is critical.
-## Note this only applies to 2D graphics; 3D graphics always use OpenGL.
-if 'linux' in sys.platform:  ## linux has numerous bugs in opengl implementation
-    useOpenGL = False
-elif 'darwin' in sys.platform: ## openGL can have a major impact on mac, but also has serious bugs
-    useOpenGL = False
-else:
-    useOpenGL = False  ## on windows there's a more even performance / bugginess tradeoff.
-
 CONFIG_OPTIONS = {
-    'useOpenGL': useOpenGL, ## by default, this is platform-dependent (see widgets/GraphicsView). Set to True or False to explicitly enable/disable opengl.
+    'useOpenGL': False, ## Set to True or False to explicitly enable/disable opengl.
     'leftButtonPan': True,  ## if false, left button drags a rubber band for zooming in viewbox
     # foreground/background take any arguments to the 'mkColor' in /pyqtgraph/functions.py
     'foreground': 'd',  ## default foreground color for axes, labels, etc.
@@ -141,62 +131,7 @@ def renamePyc(startDir):
 
 path = os.path.split(__file__)[0]
 
-## Import almost everything to make it available from a single namespace
-## don't import the more complex systems--canvas, parametertree, flowchart, dockarea
-## these must be imported separately.
-#from . import frozenSupport
-#def importModules(path, globals, locals, excludes=()):
-    #"""Import all modules residing within *path*, return a dict of name: module pairs.
-
-    #Note that *path* MUST be relative to the module doing the import.
-    #"""
-    #d = os.path.join(os.path.split(globals['__file__'])[0], path)
-    #files = set()
-    #for f in frozenSupport.listdir(d):
-        #if frozenSupport.isdir(os.path.join(d, f)) and f not in ['__pycache__', 'tests']:
-            #files.add(f)
-        #elif f[-3:] == '.py' and f != '__init__.py':
-            #files.add(f[:-3])
-        #elif f[-4:] == '.pyc' and f != '__init__.pyc':
-            #files.add(f[:-4])
-
-    #mods = {}
-    #path = path.replace(os.sep, '.')
-    #for modName in files:
-        #if modName in excludes:
-            #continue
-        #try:
-            #if len(path) > 0:
-                #modName = path + '.' + modName
-            #print( "from .%s import * " % modName)
-            #mod = __import__(modName, globals, locals, ['*'], 1)
-            #mods[modName] = mod
-        #except:
-            #import traceback
-            #traceback.print_stack()
-            #sys.excepthook(*sys.exc_info())
-            #print("[Error importing module: %s]" % modName)
-
-    #return mods
-
-#def importAll(path, globals, locals, excludes=()):
-    #"""Given a list of modules, import all names from each module into the global namespace."""
-    #mods = importModules(path, globals, locals, excludes)
-    #for mod in mods.values():
-        #if hasattr(mod, '__all__'):
-            #names = mod.__all__
-        #else:
-            #names = [n for n in dir(mod) if n[0] != '_']
-        #for k in names:
-            #if hasattr(mod, k):
-                #globals[k] = getattr(mod, k)
-
-# Dynamic imports are disabled. This causes too many problems.
-#importAll('graphicsItems', globals(), locals())
-#importAll('widgets', globals(), locals(),
-          #excludes=['MatplotlibWidget', 'RawImageWidget', 'RemoteGraphicsView'])
-
-## Attempts to work around exit crashes:
+# Attempts to work around exit crashes:
 import atexit
 
 from .colormap import *
@@ -204,6 +139,7 @@ from .functions import *
 from .graphicsItems.ArrowItem import *
 from .graphicsItems.AxisItem import *
 from .graphicsItems.BarGraphItem import *
+from .graphicsItems.BoxplotItem import *
 from .graphicsItems.ButtonItem import *
 from .graphicsItems.ColorBarItem import *
 from .graphicsItems.CurvePoint import *
@@ -227,7 +163,6 @@ from .graphicsItems.ItemGroup import *
 from .graphicsItems.LabelItem import *
 from .graphicsItems.LegendItem import *
 from .graphicsItems.LinearRegionItem import *
-from .graphicsItems.MultiPlotItem import *
 from .graphicsItems.PColorMeshItem import *
 from .graphicsItems.PlotCurveItem import *
 from .graphicsItems.PlotDataItem import *
@@ -246,7 +181,6 @@ from .GraphicsScene import GraphicsScene
 from .imageview import *
 
 # indirect imports known to be used outside of the library
-from .metaarray import MetaArray
 from .Point import Point
 from .Qt import isQObjectAlive
 from .SignalProxy import *
@@ -260,6 +194,7 @@ from .WidgetGroup import *
 from .widgets.BusyCursor import *
 from .widgets.CheckTable import *
 from .widgets.ColorButton import *
+from .widgets.ColorMapMenu import ColorMapMenu
 from .widgets.ColorMapWidget import *
 from .widgets.ComboBox import *
 from .widgets.DataFilterWidget import *
@@ -274,7 +209,6 @@ from .widgets.GroupBox import GroupBox
 from .widgets.HistogramLUTWidget import *
 from .widgets.JoystickButton import *
 from .widgets.LayoutWidget import *
-from .widgets.MultiPlotWidget import *
 from .widgets.PathButton import *
 from .widgets.PlotWidget import *
 from .widgets.ProgressDialog import *
@@ -462,5 +396,4 @@ def setPalette(app, style):
         p = style
     else:
         raise TypeError('style either be a string or QPalette')
-    app.paletteChanged.emit(p)
     app.setPalette(p)
