@@ -8,11 +8,12 @@ file format. Data structures may be nested and contain any data type as long
 as it can be converted to/from a string using repr and eval.
 """
 
+
+import contextlib
 import datetime
 import os
 import re
 import sys
-import tempfile
 from collections import OrderedDict
 
 import numpy
@@ -22,7 +23,7 @@ from .colormap import ColorMap
 from .Point import Point
 from .Qt import QtCore
 
-GLOBAL_PATH = None # so not thread safe.
+GLOBAL_PATH = None  # so not thread safe.
 
 
 class ParseError(Exception):
@@ -32,15 +33,15 @@ class ParseError(Exception):
         self.message = message
         self.fileName = fileName
         Exception.__init__(self, message)
-        
+
     def __str__(self):
         if self.fileName is None:
-            msg = "Error parsing string at line %d:\n" % self.lineNum
+            msg = f"Error parsing string at line {self.lineNum:d}:\n"
         else:
-            msg = "Error parsing config file '%s' at line %d:\n" % (self.fileName, self.lineNum)
-        msg += "%s\n%s" % (self.line, Exception.__str__(self))
+            msg = f"Error parsing config file '{self.fileName}' at line {self.lineNum:d}:\n"
+        msg += f"{self.line}\n{Exception.__str__(self)}"
         return msg
-        
+
 
 def writeConfigFile(data, fname):
     s = genString(data)
@@ -49,7 +50,6 @@ def writeConfigFile(data, fname):
 
 
 def readConfigFile(fname, **scope):
-    #cwd = os.getcwd()
     global GLOBAL_PATH
     if GLOBAL_PATH is not None:
         fname2 = os.path.join(GLOBAL_PATH, fname)
@@ -58,23 +58,25 @@ def readConfigFile(fname, **scope):
 
     GLOBAL_PATH = os.path.dirname(os.path.abspath(fname))
 
-    local = {**scope, **units.allUnits}
-    local['OrderedDict'] = OrderedDict
-    local['readConfigFile'] = readConfigFile
-    local['Point'] = Point
-    local['QtCore'] = QtCore
-    local['ColorMap'] = ColorMap
-    local['datetime'] = datetime
-    # Needed for reconstructing numpy arrays
-    local['array'] = numpy.array
+    local = {
+        **scope,
+        **units.allUnits,
+        'OrderedDict': OrderedDict,
+        'readConfigFile': readConfigFile,
+        'Point': Point,
+        'QtCore': QtCore,
+        'ColorMap': ColorMap,
+        'datetime': datetime,
+        # Needed for reconstructing numpy arrays
+        'array': numpy.array,
+    }
     for dtype in ['int8', 'uint8',
                   'int16', 'uint16', 'float16',
                   'int32', 'uint32', 'float32',
                   'int64', 'uint64', 'float64']:
         local[dtype] = getattr(numpy, dtype)
-        
+
     try:
-        #os.chdir(newDir)  ## bad.
         with open(fname, "rt") as fd:
             s = fd.read()
         s = s.replace("\r\n", "\n")
@@ -84,12 +86,11 @@ def readConfigFile(fname, **scope):
         sys.exc_info()[1].fileName = fname
         raise
     except:
-        print("Error while reading config file %s:"% fname)
+        print(f"Error while reading config file {fname}:")
         raise
-    #finally:
-        #os.chdir(cwd)
     return data
 
+
 def appendConfigFile(data, fname):
     s = genString(data)
     with open(fname, 'at') as fd:
@@ -100,117 +101,99 @@ def genString(data, indent=''):
     s = ''
     for k in data:
         sk = str(k)
-        if len(sk) == 0:
+        if not sk:
             print(data)
-            raise Exception('blank dict keys not allowed (see data above)')
+            raise ValueError('blank dict keys not allowed (see data above)')
         if sk[0] == ' ' or ':' in sk:
             print(data)
-            raise Exception('dict keys must not contain ":" or start with spaces [offending key is "%s"]' % sk)
+            raise ValueError(
+                f'dict keys must not contain ":" or start with spaces [offending key is "{sk}"]'
+            )
         if isinstance(data[k], dict):
-            s += indent + sk + ':\n'
-            s += genString(data[k], indent + '    ')
+            s += f"{indent}{sk}:\n"
+            s += genString(data[k], f'{indent}    ')
         else:
-            s += indent + sk + ': ' + repr(data[k]).replace("\n", "\\\n") + '\n'
+            line = repr(data[k]).replace("\n", "\\\n")
+            s += f"{indent}{sk}: {line}\n"
     return s
-    
+
+
 def parseString(lines, start=0, **scope):
-    
     data = OrderedDict()
     if isinstance(lines, str):
         lines = lines.replace("\\\n", "")
         lines = lines.split('\n')
-        lines = [l for l in lines if re.search(r'\S', l) and not re.match(r'\s*#', l)]  ## remove empty lines
-        
-    indent = measureIndent(lines[start])
+
+    indent = None
     ln = start - 1
-    
+    l = ''
+
     try:
         while True:
             ln += 1
-            #print ln
             if ln >= len(lines):
                 break
-            
+
             l = lines[ln]
-            
+
             ## Skip blank lines or lines starting with #
-            if re.match(r'\s*#', l) or not re.search(r'\S', l):
+            if not _line_is_real(l):
                 continue
-            
+
             ## Measure line indentation, make sure it is correct for this level
             lineInd = measureIndent(l)
+            if indent is None:
+                indent = lineInd
             if lineInd < indent:
                 ln -= 1
                 break
             if lineInd > indent:
-                #print lineInd, indent
-                raise ParseError('Indentation is incorrect. Expected %d, got %d' % (indent, lineInd), ln+1, l)
-            
-            
+                raise ParseError(f'Indentation is incorrect. Expected {indent:d}, got {lineInd:d}', ln + 1, l)
+
             if ':' not in l:
-                raise ParseError('Missing colon', ln+1, l)
-            
-            (k, p, v) = l.partition(':')
+                raise ParseError('Missing colon', ln + 1, l)
+
+            k, _, v = l.partition(':')
             k = k.strip()
             v = v.strip()
-            
+
             ## set up local variables to use for eval
             if len(k) < 1:
-                raise ParseError('Missing name preceding colon', ln+1, l)
-            if k[0] == '(' and k[-1] == ')':  ## If the key looks like a tuple, try evaluating it.
-                try:
+                raise ParseError('Missing name preceding colon', ln + 1, l)
+            if k[0] == '(' and k[-1] == ')':  # If the key looks like a tuple, try evaluating it.
+                with contextlib.suppress(Exception):  # If tuple conversion fails, keep the string
                     k1 = eval(k, scope)
                     if type(k1) is tuple:
                         k = k1
-                except:
-                    # If tuple conversion fails, keep the string
-                    pass
-            if re.search(r'\S', v) and v[0] != '#':  ## eval the value
+            if _line_is_real(v):  # eval the value
                 try:
                     val = eval(v, scope)
-                except:
-                    ex = sys.exc_info()[1]
-                    raise ParseError("Error evaluating expression '%s': [%s: %s]" % (v, ex.__class__.__name__, str(ex)), (ln+1), l)
+                except Exception as ex:
+                    raise ParseError(
+                        f"Error evaluating expression '{v}': [{ex.__class__.__name__}: {ex}]", ln + 1, l
+                    ) from ex
             else:
-                if ln+1 >= len(lines) or measureIndent(lines[ln+1]) <= indent:
-                    #print "blank dict"
+                next_real_ln = next((i for i in range(ln + 1, len(lines)) if _line_is_real(lines[i])), len(lines))
+                if ln + 1 >= len(lines) or measureIndent(lines[next_real_ln]) <= indent:
                     val = {}
                 else:
-                    #print "Going deeper..", ln+1
-                    (ln, val) = parseString(lines, start=ln+1, **scope)
+                    ln, val = parseString(lines, start=ln + 1, **scope)
+            if k in data:
+                raise ParseError(f'Duplicate key: {k}', ln + 1, l)
             data[k] = val
-        #print k, repr(val)
     except ParseError:
         raise
-    except:
-        ex = sys.exc_info()[1]
-        raise ParseError("%s: %s" % (ex.__class__.__name__, str(ex)), ln+1, l)
-    #print "Returning shallower..", ln+1
-    return (ln, data)
-    
+    except Exception as ex:
+        raise ParseError(f"{ex.__class__.__name__}: {ex}", ln + 1, l) from ex
+    return ln, data
+
+
+def _line_is_real(line):
+    return not re.match(r'\s*#', line) and re.search(r'\S', line)
+
+
 def measureIndent(s):
     n = 0
     while n < len(s) and s[n] == ' ':
         n += 1
     return n
-
-if __name__ == '__main__':
-    cf = """
-key: 'value'
-key2:              ##comment
-                   ##comment
-    key21: 'value' ## comment
-                   ##comment
-    key22: [1,2,3]
-    key23: 234  #comment
-    """
-    with tempfile.NamedTemporaryFile(encoding="utf-8") as tf:
-        tf.write(cf.encode("utf-8"))
-        print("=== Test:===")
-        for num, line in enumerate(cf.split('\n'), start=1):
-            print("%02d   %s" % (num, line))
-        print(cf)
-        print("============")
-        data = readConfigFile(tf.name)
-    print(data)
-    
