@@ -26,15 +26,6 @@ from numpy import ndarray
 
 from .Qt import QT_LIB, QtCore
 from .util import cprint
-
-if sys.version.startswith("3.8") and QT_LIB == "PySide2":
-    from .Qt import PySide2
-    if tuple(map(int, PySide2.__version__.split("."))) < (5, 14) \
-        and PySide2.__version__.startswith(QtCore.__version__):
-        warnings.warn(
-            "Due to PYSIDE-1140, ThreadChase and ThreadColor will not work" +
-            " on pip-installed PySide2 bindings < 5.14"
-        )
 from .util.mutex import Mutex
 
 
@@ -648,10 +639,13 @@ def get_all_objects():
     gcl = gc.get_objects()
     olist = {}
     _getr(gcl, olist)
-    
-    del olist[id(olist)]
-    del olist[id(gcl)]
-    del olist[id(sys._getframe())]
+
+    # Remove internally created objects
+    for key in (id(olist), id(gcl), id(sys._getframe())):
+        try:
+            del olist[key]
+        except KeyError:
+            pass
     return olist
 
 
@@ -817,8 +811,14 @@ class ObjTracker(object):
         gc.collect()
         objs = get_all_objects()
         frame = sys._getframe()
-        del objs[id(frame)]  ## ignore the current frame 
-        del objs[id(frame.f_code)]
+        try:
+            del objs[id(frame)]  ## ignore the current frame 
+        except KeyError:
+            pass
+        try:
+            del objs[id(frame.f_code)]
+        except KeyError:
+            pass
         
         ignoreTypes = [int]
         refs = {}
@@ -1192,19 +1192,7 @@ class ThreadTrace(object):
                     if id == threading.current_thread().ident:
                         continue
 
-                    # try to determine a thread name
-                    try:
-                        name = threading._active.get(id, None)
-                    except:
-                        name = None
-                    if name is None:
-                        try:
-                            # QThread._names must be manually set by thread creators.
-                            name = QtCore.QThread._names.get(id)
-                        except:
-                            name = None
-                    if name is None:
-                        name = "???"
+                    name = threadName(id)
 
                     printFile.write("<< thread %d \"%s\" >>\n" % (id, name))
                     tb = str(''.join(traceback.format_stack(frame)))
@@ -1217,6 +1205,46 @@ class ThreadTrace(object):
                 time.sleep(self.interval)
 
 
+def threadName(threadId=None):
+    """Return a string name for a thread id.
+
+    If *threadId* is None, then the current thread's id is used.
+
+    This attempts to look up thread names either from `threading._active`, or from
+    QThread._names. However, note that the latter does not exist by default; rather
+    you must manually add id:name pairs to a dictionary there::
+
+        # for python threads:
+        t1 = threading.Thread(name="mythread")
+
+        # for Qt threads:
+        class Thread(Qt.QThread):
+            def __init__(self, name):
+                self._threadname = name
+                if not hasattr(Qt.QThread, '_names'):
+                    Qt.QThread._names = {}
+                Qt.QThread.__init__(self, *args, **kwds)
+            def run(self):
+                Qt.QThread._names[threading.current_thread().ident] = self._threadname
+    """
+    if threadId is None:
+        threadId = threading.current_thread().ident
+    
+    try:
+        name = threading._active.get(threadId, None)
+    except Exception:
+        name = None
+    if name is None:
+        try:
+            # QThread._names must be manually set by thread creators.
+            name = QtCore.QThread._names.get(threadId)
+        except Exception:
+            name = None
+    if name is None:
+        name = "???"
+    return name
+
+
 class ThreadColor(object):
     """
     Wrapper on stdout/stderr that colors text by the current thread ID.
