@@ -38,12 +38,11 @@ data = np.abs(np.fromfunction(psi, (50,50,100)))
 print("Generating isosurface..")
 verts, faces = pg.isosurface(data, data.max()/4.)
 
-md = gl.MeshData(vertexes=verts, faces=faces)
-
-colors = np.ones((md.faceCount(), 4), dtype=float)
+colors = np.ones((len(verts), 4), dtype=np.float32)
 colors[:,3] = 0.2
 colors[:,2] = np.linspace(0, 1, colors.shape[0])
-md.setFaceColors(colors)
+md = gl.MeshData(vertexes=verts, faces=faces, vertexColors=colors)
+
 m1 = gl.GLMeshItem(meshdata=md, smooth=False, shader='balloon')
 m1.setGLOptions('additive')
 
