@@ -18,14 +18,27 @@ class CSVExporter(Exporter):
     windows = []
     def __init__(self, item):
         Exporter.__init__(self, item)
-        self.params = Parameter(name='params', type='group', children=[
-            {'name': 'separator', 'title': translate("Exporter", 'separator'), 'type': 'list', 'value': 'comma', 'limits': ['comma', 'tab']},
-            {'name': 'precision', 'title': translate("Exporter", 'precision'), 'type': 'int', 'value': 10, 'limits': [0, None]},
+        self.params = Parameter.create(name='params', type='group', children=[
+            {
+                'name': 'separator',
+                'title': translate("Exporter", 'separator'),
+                'type': 'list',
+                'value': 'comma',
+                'limits': ['comma', 'tab']
+            },
+            {
+                'name': 'precision',
+                'title': translate("Exporter", 'precision'),
+                'type': 'int',
+                'value': 10,
+                'limits': [0, None]
+            },
             {
                 'name': 'columnMode',
                 'title': translate("Exporter", 'columnMode'),
                 'type': 'list',
-                'limits': ['(x,y) per plot', '(x,y,y,y) for all plots']
+                'limits': ['(x,y) per plot', '(x,y,y,y) for all plots'],
+                'value': '(x,y) per plot',
             }
         ])
 
@@ -74,7 +87,6 @@ class CSVExporter(Exporter):
         if cd[0] is None:
             # no data found, break out...
             return None
-        self.data.append(cd)
 
         index = next(self.index_counter)
         if plotDataItem.name() is not None:
@@ -87,8 +99,10 @@ class CSVExporter(Exporter):
         appendAllX = self.params['columnMode'] == '(x,y) per plot'
         if appendAllX or index == 0:
             self.header.extend([xName, yName])
+            self.data.append(cd)
         else:
             self.header.extend([yName])
+            self.data.append([cd[1]])
         return None
 
     def export(self, fileName=None):
