@@ -1,16 +1,18 @@
+__all__ = ['GraphicsItem']
+
 import operator
-import warnings
 import weakref
 from collections import OrderedDict
 from functools import reduce
 from math import hypot
+from typing import Optional
+from xml.etree.ElementTree import Element
 
 from .. import functions as fn
 from ..GraphicsScene import GraphicsScene
 from ..Point import Point
 from ..Qt import QtCore, QtWidgets, isQObjectAlive
 
-__all__ = ['GraphicsItem']
 
 # Recipe from https://docs.python.org/3.8/library/collections.html#collections.OrderedDict
 # slightly adapted for Python 3.7 compatibility
@@ -48,26 +50,14 @@ class GraphicsItem(object):
     """
     _pixelVectorGlobalCache = LRU(100)
 
-    def __init__(self, register=None):
-        if not hasattr(self, '_qtBaseClass'):
-            for b in self.__class__.__bases__:
-                if issubclass(b, QtWidgets.QGraphicsItem):
-                    self.__class__._qtBaseClass = b
-                    break
-        if not hasattr(self, '_qtBaseClass'):
-            raise Exception('Could not determine Qt base class for GraphicsItem: %s' % str(self))
-
+    def __init__(self):
         self._pixelVectorCache = [None, None]
         self._viewWidget = None
         self._viewBox = None
         self._connectedView = None
         self._exportOpts = False   ## If False, not currently exporting. Otherwise, contains dict of export options.
         self._cachedView = None
-        if register is not None and register:
-            warnings.warn(
-                "'register' argument is deprecated and does nothing, will be removed in 0.13",
-                DeprecationWarning, stacklevel=2
-            )
+
 
     def getViewWidget(self):
         """
@@ -124,21 +114,15 @@ class GraphicsItem(object):
     def forgetViewBox(self):
         self._viewBox = None
         
-    def deviceTransform(self, viewportTransform=None):
+    def deviceTransform_(self):
         """
         Return the transform that converts local item coordinates to device coordinates (usually pixels).
-        Extends deviceTransform to automatically determine the viewportTransform.
         """
-        if viewportTransform is None:
-            view = self.getViewWidget()
-            if view is None:
-                return None
-            viewportTransform = view.viewportTransform()
-        dt = self._qtBaseClass.deviceTransform(self, viewportTransform)
+        if (view := self.getViewWidget()) is None:
+            return None
+        viewportTransform = view.viewportTransform()
+        dt = self.deviceTransform(viewportTransform)
         
-        #xmag = abs(dt.m11())+abs(dt.m12())
-        #ymag = abs(dt.m21())+abs(dt.m22())
-        #if xmag * ymag == 0: 
         if dt.determinant() == 0:  ## occurs when deviceTransform is invalid because widget has not been displayed
             return None
         else:
@@ -152,15 +136,9 @@ class GraphicsItem(object):
         if view is None:
             return None
         if hasattr(view, 'implements') and view.implements('ViewBox'):
-            tr = self.itemTransform(view.innerSceneItem())
-            if isinstance(tr, tuple):
-                tr = tr[0]   ## difference between pyside and pyqt
-            return tr
+            return self.itemTransform(view.innerSceneItem())[0]
         else:
             return self.sceneTransform()
-            #return self.deviceTransform(view.viewportTransform())
-
-
 
     def getBoundingParents(self):
         """Return a list of parents to this item that have child clipping enabled."""
@@ -211,8 +189,7 @@ class GraphicsItem(object):
         ## This is an expensive function that gets called very frequently.
         ## We have two levels of cache to try speeding things up.
         
-        dt = self.deviceTransform()
-        if dt is None:
+        if (dt := self.deviceTransform_()) is None:
             return None, None
             
         ## Ignore translation. If the translation is much larger than the scale
@@ -287,7 +264,7 @@ class GraphicsItem(object):
         #pv = Point(dti.map(normView)-dti.map(Point(0,0))), Point(dti.map(normOrtho)-dti.map(Point(0,0)))
         pv = Point(dti.map(normView).p2()), Point(dti.map(normOrtho).p2())
         self._pixelVectorCache[1] = pv
-        self._pixelVectorCache[0] = dt
+        self._pixelVectorCache[0] = key
         self._pixelVectorGlobalCache[key] = pv
         return self._pixelVectorCache[1]
     
@@ -315,16 +292,14 @@ class GraphicsItem(object):
 
     def pixelWidth(self):
         ## deprecated
-        vt = self.deviceTransform()
-        if vt is None:
+        if (vt := self.deviceTransform_()) is None:
             return 0
         vt = fn.invertQTransform(vt)
         return vt.map(QtCore.QLineF(0, 0, 1, 0)).length()
         
     def pixelHeight(self):
         ## deprecated
-        vt = self.deviceTransform()
-        if vt is None:
+        if (vt := self.deviceTransform_()) is None:
             return 0
         vt = fn.invertQTransform(vt)
         return vt.map(QtCore.QLineF(0, 0, 0, 1)).length()
@@ -336,8 +311,7 @@ class GraphicsItem(object):
         Return *obj* mapped from local coordinates to device coordinates (pixels).
         If there is no device mapping available, return None.
         """
-        vt = self.deviceTransform()
-        if vt is None:
+        if (vt := self.deviceTransform_()) is None:
             return None
         return vt.map(obj)
         
@@ -346,8 +320,7 @@ class GraphicsItem(object):
         Return *obj* mapped from device coordinates (pixels) to local coordinates.
         If there is no device mapping available, return None.
         """
-        vt = self.deviceTransform()
-        if vt is None:
+        if (vt := self.deviceTransform_()) is None:
             return None
         if isinstance(obj, QtCore.QPoint):
             obj = QtCore.QPointF(obj)
@@ -359,8 +332,7 @@ class GraphicsItem(object):
         Return *rect* mapped from local coordinates to device coordinates (pixels).
         If there is no device mapping available, return None.
         """
-        vt = self.deviceTransform()
-        if vt is None:
+        if (vt := self.deviceTransform_()) is None:
             return None
         return vt.mapRect(rect)
 
@@ -369,8 +341,7 @@ class GraphicsItem(object):
         Return *rect* mapped from device coordinates (pixels) to local coordinates.
         If there is no device mapping available, return None.
         """
-        vt = self.deviceTransform()
-        if vt is None:
+        if (vt := self.deviceTransform_()) is None:
             return None
         vt = fn.invertQTransform(vt)
         return vt.mapRect(rect)
@@ -401,39 +372,9 @@ class GraphicsItem(object):
         vt = fn.invertQTransform(vt)
         return vt.mapRect(obj)
 
-    def pos(self):
-        return Point(self._qtBaseClass.pos(self))
-    
     def viewPos(self):
         return self.mapToView(self.mapFromParent(self.pos()))
     
-    def parentItem(self):
-        ## PyQt bug -- some items are returned incorrectly.
-        return GraphicsScene.translateGraphicsItem(self._qtBaseClass.parentItem(self))
-        
-    def setParentItem(self, parent):
-        ## Workaround for Qt bug: https://bugreports.qt-project.org/browse/QTBUG-18616
-        if parent is not None:
-            pscene = parent.scene()
-            if pscene is not None and self.scene() is not pscene:
-                pscene.addItem(self)
-        return self._qtBaseClass.setParentItem(self, parent)
-    
-    def childItems(self):
-        ## PyQt bug -- some child items are returned incorrectly.
-        return list(map(GraphicsScene.translateGraphicsItem, self._qtBaseClass.childItems(self)))
-
-
-    def sceneTransform(self):
-        ## Qt bug: do no allow access to sceneTransform() until 
-        ## the item has a scene.
-        
-        if self.scene() is None:
-            return self.transform()
-        else:
-            return self._qtBaseClass.sceneTransform(self)
-
-
     def transformAngle(self, relativeItem=None):
         """Return the rotation produced by this item's transform (this assumes there is no shear in the transform)
         If relativeItem is given, then the angle is determined relative to that item.
@@ -441,36 +382,16 @@ class GraphicsItem(object):
         if relativeItem is None:
             relativeItem = self.parentItem()
 
-        tr = self.itemTransform(relativeItem)
-        if isinstance(tr, tuple):  ## difference between pyside and pyqt
-            tr = tr[0]
+        tr = self.itemTransform(relativeItem)[0]
         vec = tr.map(QtCore.QLineF(0,0,1,0))
         return vec.angleTo(QtCore.QLineF(vec.p1(), vec.p1()+QtCore.QPointF(1,0)))
         
-    #def itemChange(self, change, value):
-        #ret = self._qtBaseClass.itemChange(self, change, value)
-        #if change == self.GraphicsItemChange.ItemParentHasChanged or change == self.ItemSceneHasChanged:
-            #print "Item scene changed:", self
-            #self.setChildScene(self)  ## This is bizarre.
-        #return ret
-
-    #def setChildScene(self, ch):
-        #scene = self.scene()
-        #for ch2 in ch.childItems():
-            #if ch2.scene() is not scene:
-                #print "item", ch2, "has different scene:", ch2.scene(), scene
-                #scene.addItem(ch2)
-                #QtWidgets.QApplication.processEvents()
-                #print "   --> ", ch2.scene()
-            #self.setChildScene(ch2)
-
-    def parentChanged(self):
+    def changeParent(self):
         """Called when the item's parent has changed. 
         This method handles connecting / disconnecting from ViewBox signals
         to make sure viewRangeChanged works properly. It should generally be 
         extended, not overridden."""
         self._updateView()
-        
 
     def _updateView(self):
         ## called to see whether this item has a new view to connect to
@@ -501,10 +422,9 @@ class GraphicsItem(object):
 
         ## disconnect from previous view
         if oldView is not None:
-            for signal, slot in [('sigRangeChanged', self.viewRangeChanged),
-                                 ('sigDeviceRangeChanged', self.viewRangeChanged), 
-                                 ('sigTransformChanged', self.viewTransformChanged), 
-                                 ('sigDeviceTransformChanged', self.viewTransformChanged)]:
+            Device = 'Device' if hasattr(oldView, 'sigDeviceRangeChanged') else ''
+            for signal, slot in [(f'sig{Device}RangeChanged', self.viewRangeChanged),
+                                 (f'sig{Device}TransformChanged', self.viewTransformChanged)]:
                 try:
                     getattr(oldView, signal).disconnect(slot)
                 except (TypeError, AttributeError, RuntimeError):
@@ -550,6 +470,7 @@ class GraphicsItem(object):
         
         
 
+    @QtCore.Slot()
     def viewRangeChanged(self):
         """
         Called whenever the view coordinates of the ViewBox containing this item have changed.
@@ -557,18 +478,15 @@ class GraphicsItem(object):
         # when this is called, _cachedView is not invalidated.
         # this means that for functions overriding viewRangeChanged, viewRect() may be stale.
     
+    @QtCore.Slot()
     def viewTransformChanged(self):
         """
         Called whenever the transformation matrix of the view has changed.
-        (eg, the view range has changed or the view was resized)
+        For example, when the view range has changed or the view was resized.
         Invalidates the viewRect cache.
         """
         self._cachedView = None
     
-    #def prepareGeometryChange(self):
-        #self._qtBaseClass.prepareGeometryChange(self)
-        #self.informViewBoundsChanged()
-        
     def informViewBoundsChanged(self):
         """
         Inform this item's container ViewBox that the bounds of this item have changed.
@@ -580,7 +498,6 @@ class GraphicsItem(object):
     
     def childrenShape(self):
         """Return the union of the shapes of all descendants of this item in local coordinates."""
-        childs = self.allChildItems()
         shapes = [self.mapFromItem(c, c.shape()) for c in self.allChildItems()]
         return reduce(operator.add, shapes)
     
@@ -610,9 +527,40 @@ class GraphicsItem(object):
         else:
             self._exportOpts = False
     
-    #def update(self):
-        #self._qtBaseClass.update(self)
-        #print "Update:", self
-
     def getContextMenus(self, event):
         return [self.getMenu()] if hasattr(self, "getMenu") else []
+
+    def generateSvg(
+            self,
+            nodes: dict[str, Element]
+    ) -> Optional[tuple[Element, list[Element]]]:
+        """Method to override to manually specify the SVG writer mechanism.
+
+        Parameters
+        ----------
+        nodes
+            Dictionary keyed by the name of graphics items and the XML
+            representation of the the item that can be written as valid
+            SVG.
+        
+        Returns
+        -------
+        tuple
+            First element is the top level group for this item. The
+            second element is a list of xml Elements corresponding to the
+            child nodes of the item.
+        None
+            Return None if no XML is needed for rendering
+
+        Raises
+        ------
+        NotImplementedError
+            override method to implement in subclasses of GraphicsItem
+
+        See Also
+        --------
+        pyqtgraph.exporters.SVGExporter._generateItemSvg
+            The generic and default implementation
+
+        """
+        raise NotImplementedError
