@@ -12,6 +12,7 @@ PARAM_NAMES = {}
 
 _PARAM_ITEM_TYPES = {}
 
+
 def registerParameterItemType(name, itemCls, parameterCls=None, override=False):
     """
     Similar to :func:`registerParameterType`, but works on ParameterItems. This is useful for Parameters where the
@@ -21,7 +22,9 @@ def registerParameterItemType(name, itemCls, parameterCls=None, override=False):
     """
     global _PARAM_ITEM_TYPES
     if name in _PARAM_ITEM_TYPES and not override:
-        raise Exception("Parameter item type '%s' already exists (use override=True to replace)" % name)
+        raise ValueError(
+            f"Parameter item type '{name}' already exists (use override=True to replace)"
+        )
 
     parameterCls = parameterCls or Parameter
     _PARAM_ITEM_TYPES[name] = itemCls
@@ -36,14 +39,16 @@ def registerParameterType(name, cls, override=False):
     """
     global PARAM_TYPES
     if name in PARAM_TYPES and not override:
-        raise Exception("Parameter type '%s' already exists (use override=True to replace)" % name)
+        raise ValueError(f"Parameter type '{name}' already exists (use override=True to replace)")
     PARAM_TYPES[name] = cls
     PARAM_NAMES[cls] = name
 
+
 def __reload__(old):
     PARAM_TYPES.update(old.get('PARAM_TYPES', {}))
     PARAM_NAMES.update(old.get('PARAM_NAMES', {}))
 
+
 class Parameter(QtCore.QObject):
     """
     A Parameter is the basic unit of data in a parameter tree. Each parameter has
@@ -55,7 +60,7 @@ class Parameter(QtCore.QObject):
     
     Note: It is fairly uncommon to use the Parameter class directly; mostly you 
     will use subclasses which provide specialized type and data handling. The static
-    pethod Parameter.create(...) is an easy way to generate instances of these subclasses.
+    method Parameter.create(...) is an easy way to generate instances of these subclasses.
        
     For more Parameter types, see ParameterTree.parameterTypes module.
     
@@ -87,8 +92,6 @@ class Parameter(QtCore.QObject):
     ## name, type, limits, etc.
     ## can also carry UI hints (slider vs spinbox, etc.)
 
-    itemClass = None
-    
     sigValueChanged = QtCore.Signal(object, object)  ## self, value   emitted when value is finished being edited
     sigValueChanging = QtCore.Signal(object, object)  ## self, value  emitted as value is being edited
     
@@ -119,9 +122,9 @@ class Parameter(QtCore.QObject):
         #except KeyError:
             #pass
         #return QtCore.QObject.__new__(cls, *args, **opts)
-    
-    @staticmethod
-    def create(**opts):
+
+    @classmethod
+    def create(cls, **opts):
         """
         Static method that creates a new Parameter (or subclass) instance using 
         opts['type'] to select the appropriate class.
@@ -131,11 +134,11 @@ class Parameter(QtCore.QObject):
         """
         typ = opts.get('type', None)
         if typ is None:
-            cls = Parameter
+            klass = cls
         else:
-            cls = PARAM_TYPES[opts['type']]
-        return cls(**opts)
-    
+            klass = PARAM_TYPES[opts['type']]
+        return klass(**opts)
+
     def __init__(self, **opts):
         """
         Initialize a Parameter object. Although it is rare to directly create a
@@ -179,9 +182,7 @@ class Parameter(QtCore.QObject):
                                      (default=None; added in version 0.9.9)
         =======================      =========================================================
         """
-        
-        
-        QtCore.QObject.__init__(self)
+        super().__init__()
         
         self.opts = {
             'type': None,
@@ -194,36 +195,34 @@ class Parameter(QtCore.QObject):
             'expanded': True,
             'syncExpanded': False,
             'title': None,
-            #'limits': None,  ## This is a bad plan--each parameter type may have a different data type for limits.
+            # The following intentionally excluded; each parameter type may have a different data type for limits.
+            # 'limits': None,
         }
-        value = opts.get('value', None)
-        name = opts.get('name', None)
+        try:
+            name = opts['name']
+        except KeyError:
+            raise KeyError("Parameter must have a name specified")
         self.opts.update(opts)
-        self.opts['value'] = None  # will be set later.
         self.opts['name'] = None
-        
+
         self.childs = []
         self.names = {}   ## map name:child
         self.items = weakref.WeakKeyDictionary()  ## keeps track of tree items representing this parameter
         self._parent = None
         self.treeStateChanges = []  ## cache of tree state changes to be delivered on next emit
         self.blockTreeChangeEmit = 0
-        #self.monitoringChildren = False  ## prevent calling monitorChildren more than once
-        
-        if not isinstance(name, str):
-            raise Exception("Parameter must have a string name specified in opts.")
         self.setName(name)
-        
+
         self.addChildren(self.opts.pop('children', []))
-        
+        if 'value' in self.opts and 'default' not in self.opts:
+            self.opts['default'] = self.opts['value']
+        value = self.opts.get('value', self.opts.get('default'))
+        modified = 'value' in self.opts
         if value is not None:
             self.setValue(value)
+        self._modifiedSinceReset = modified
 
-        if 'default' not in self.opts:
-            self.opts['default'] = None
-            self.setDefault(self.opts['value'])
-    
-        ## Connect all state changed signals to the general sigStateChanged
+        # Connect all state changed signals to the general sigStateChanged
         self.sigValueChanged.connect(self._emitValueChanged)
         self.sigChildAdded.connect(self._emitChildAddedChanged)
         self.sigChildRemoved.connect(self._emitChildRemovedChanged)
@@ -234,9 +233,13 @@ class Parameter(QtCore.QObject):
         self.sigOptionsChanged.connect(self._emitOptionsChanged)
         self.sigContextMenu.connect(self._emitContextMenuChanged)
 
-        
-        #self.watchParam(self)  ## emit treechange signals if our own state changes
-        
+    @property
+    def itemClass(self):
+        """
+        The class of ParameterItem to use when displaying this parameter in a ParameterTree.
+        """
+        return ParameterItem
+
     def name(self):
         """Return the name of this Parameter."""
         return self.opts['name']
@@ -258,12 +261,13 @@ class Parameter(QtCore.QObject):
     def setName(self, name):
         """Attempt to change the name of this parameter; return the actual name. 
         (The parameter may reject the name change or automatically pick a different name)"""
-        if self.opts['strictNaming']:
-            if len(name) < 1 or re.search(r'\W', name) or re.match(r'\d', name[0]):
-                raise Exception("Parameter name '%s' is invalid. (Must contain only alphanumeric and underscore characters and may not start with a number)" % name)
+        if self.opts['strictNaming'] and (len(name) < 1 or re.search(r'\W', name) or re.match(r'\d', name[0])):
+            raise ValueError(
+                f"Parameter name '{name}' is invalid. (Must contain only alphanumeric and underscore characters and "
+                f"may not start with a number)")
         parent = self.parent()
         if parent is not None:
-            name = parent._renameChild(self, name)  ## first ask parent if it's ok to rename
+            name = parent._renameChild(self, name)  # first ask parent if it's ok to rename
         if self.opts['name'] != name:
             self.opts['name'] = name
             self.sigNameChanged.emit(self, name)
@@ -286,7 +290,7 @@ class Parameter(QtCore.QObject):
         global PARAM_TYPES
         cls = PARAM_TYPES.get(typ, None)
         if cls is None:
-            raise Exception("Type name '%s' is not registered." % str(typ))
+            raise ValueError(f"Type name '{typ}' is not registered.")
         return self.__class__ is cls
         
     def childPath(self, child):
@@ -307,31 +311,36 @@ class Parameter(QtCore.QObject):
         Set the value of this Parameter; return the actual value that was set.
         (this may be different from the value that was requested)
         """
-        try:
-            if blockSignal is not None:
-                self.sigValueChanged.disconnect(blockSignal)
-            value = self._interpretValue(value)
-            if fn.eq(self.opts['value'], value):
-                return value
-            self.opts['value'] = value
+        value = self._interpretValue(value)
+        if fn.eq(self.opts.get('value', None), value):
+            return value
+        self._modifiedSinceReset = True
+        self.opts['value'] = value
+        if not blockSignal:
             self.sigValueChanged.emit(self, value)  # value might change after signal is received by tree item
-        finally:
-            if blockSignal is not None:
-                self.sigValueChanged.connect(blockSignal)
-            
+
         return self.opts['value']
 
     def _interpretValue(self, v):
         return v
 
+    def hasValue(self):
+        """Return True if this Parameter has a value set."""
+        return 'value' in self.opts
+
     def value(self):
         """
-        Return the value of this Parameter.
+        Return the value of this Parameter. Raises ValueError if no value has been set.
         """
-        return self.opts['value']
+        try:
+            return self.opts['value']
+        except KeyError:
+            raise ValueError("No Value has been set")
 
     def getValues(self):
-        """Return a tree of all values that are children of this parameter"""
+        """
+        Return a tree of all values that are children of this parameter. Raises ValueError if any child has no value.
+        """
         vals = OrderedDict()
         for ch in self:
             vals[ch.name()] = (ch.value(), ch.getValues())
@@ -351,9 +360,12 @@ class Parameter(QtCore.QObject):
                 global PARAM_NAMES
                 state['type'] = PARAM_NAMES.get(type(self), None)
         elif filter == 'user':
-            state = {'value': self.value()}
+            if self.hasValue():
+                state = {'value': self.value()}
+            else:
+                state = {}
         else:
-            raise ValueError("Unrecognized filter argument: '%s'" % filter)
+            raise ValueError(f"Unrecognized filter argument: '{filter}'")
 
         ch = OrderedDict([(ch.name(), ch.saveState(filter=filter)) for ch in self])
         if len(ch) > 0:
@@ -393,7 +405,6 @@ class Parameter(QtCore.QObject):
             
             ptr = 0  ## pointer to first child that has not been restored yet
             foundChilds = set()
-            #print "==============", self.name()
             
             for ch in childState:
                 name = ch['name']
@@ -436,33 +447,45 @@ class Parameter(QtCore.QObject):
         finally:
             if blockSignals:
                 self.unblockTreeChangeSignal()
-            
-            
-        
+
+    def valueModifiedSinceResetToDefault(self):
+        """Return True if this parameter's value has been changed since the last time
+        it was reset to its default value."""
+        return self._modifiedSinceReset
+
     def defaultValue(self):
-        """Return the default value for this parameter."""
-        return self.opts['default']
+        """Return the default value for this parameter. Raises ValueError if no default."""
+        return self.opts.get('default')
         
-    def setDefault(self, val):
-        """Set the default value for this parameter."""
-        if self.opts['default'] == val:
+    def setDefault(self, val, updatePristineValues=False):
+        """Set the default value for this parameter. If updatePristineValues is True, then
+        any values that haven't been modified since the last time they were reset to default
+        will be updated to the new default value (default: False)."""
+        if self.opts.get('default') == val:
             return
         self.opts['default'] = val
+        if 'value' not in self.opts or (updatePristineValues and not self.valueModifiedSinceResetToDefault()):
+            self.setToDefault()
+        if not self.valueIsDefault():
+            self._modifiedSinceReset = True
         self.sigDefaultChanged.emit(self, val)
 
     def setToDefault(self):
-        """Set this parameter's value to the default."""
-        if self.hasDefault():
+        """Set this parameter's value to the default. Raises ValueError if no default is set."""
+        with self.treeChangeBlocker():
             self.setValue(self.defaultValue())
+            self._modifiedSinceReset = False
 
     def hasDefault(self):
         """Returns True if this parameter has a default value."""
-        return self.opts['default'] is not None
+        return self.opts.get('default') is not None
         
     def valueIsDefault(self):
         """Returns True if this parameter's value is equal to the default value."""
+        if not self.hasValue() or not self.hasDefault():
+            return False
         return fn.eq(self.value(), self.defaultValue())
-        
+
     def setLimits(self, limits):
         """Set limits on the acceptable values for this parameter. 
         The format of limits depends on the type of the parameter and
@@ -502,7 +525,8 @@ class Parameter(QtCore.QObject):
         Set any arbitrary options on this parameter.
         The exact behavior of this function will depend on the parameter type, but
         most parameters will accept a common set of options: value, name, limits,
-        default, readonly, removable, renamable, visible, enabled, expanded and syncExpanded.
+        default, readonly, removable, renamable, visible, enabled, expanded and
+        syncExpanded.
         
         See :func:`Parameter.__init__ <pyqtgraph.parametertree.Parameter.__init__>`
         for more information on default options.
@@ -532,30 +556,39 @@ class Parameter(QtCore.QObject):
         self.treeStateChanges.append((self, changeDesc, data))
         self.emitTreeChanges()
 
+    @QtCore.Slot(object, object)
     def _emitValueChanged(self, param, data):
         self.emitStateChanged("value", data)
 
+    @QtCore.Slot(object, object, object)
     def _emitChildAddedChanged(self, param, *data):
         self.emitStateChanged("childAdded", data)
 
+    @QtCore.Slot(object, object)
     def _emitChildRemovedChanged(self, param, data):
         self.emitStateChanged("childRemoved", data)
 
+    @QtCore.Slot(object, object)
     def _emitParentChanged(self, param, data):
         self.emitStateChanged("parent", data)
 
+    @QtCore.Slot(object, object)
     def _emitLimitsChanged(self, param, data):
         self.emitStateChanged("limits", data)
 
+    @QtCore.Slot(object, object)
     def _emitDefaultChanged(self, param, data):
         self.emitStateChanged("default", data)
 
+    @QtCore.Slot(object, object)
     def _emitNameChanged(self, param, data):
         self.emitStateChanged("name", data)
 
+    @QtCore.Slot(object, object)
     def _emitOptionsChanged(self, param, data):
         self.emitStateChanged("options", data)
 
+    @QtCore.Slot(object, object)
     def _emitContextMenuChanged(self, param, data):
         self.emitStateChanged("contextMenu", data)
 
@@ -571,15 +604,14 @@ class Parameter(QtCore.QObject):
         itemClass = self.itemClass or _PARAM_ITEM_TYPES.get(self.opts['type'], ParameterItem)
         return itemClass(self, depth)
 
-
-    def addChild(self, child, autoIncrementName=None):
+    def addChild(self, child, autoIncrementName=None, existOk=False):
         """
         Add another parameter to the end of this parameter's child list.
         
-        See insertChild() for a description of the *autoIncrementName* 
-        argument.
+        See insertChild() for a description of the *autoIncrementName* and *existOk*
+        arguments.
         """
-        return self.insertChild(len(self.childs), child, autoIncrementName=autoIncrementName)
+        return self.insertChild(len(self.childs), child, autoIncrementName=autoIncrementName, existOk=existOk)
 
     def addChildren(self, children):
         """
@@ -599,9 +631,8 @@ class Parameter(QtCore.QObject):
         for chOpts in children:
             #print self, "Add child:", type(chOpts), id(chOpts)
             self.addChild(chOpts)
-        
-        
-    def insertChild(self, pos, child, autoIncrementName=None):
+
+    def insertChild(self, pos, child, autoIncrementName=None, existOk=False):
         """
         Insert a new child at pos.
         If pos is a Parameter, then insert at the position of that Parameter.
@@ -612,6 +643,9 @@ class Parameter(QtCore.QObject):
         the name will be adjusted to avoid prior name collisions. This 
         behavior may be overridden by specifying the *autoIncrementName* 
         argument. This argument was added in version 0.9.9.
+
+        If 'autoIncrementName' is *False*, an error is raised when the inserted child already exists. However, if
+        'existOk' is *True*, the existing child will be returned instead, and this child will *not* be inserted.
         """
         if isinstance(child, dict):
             child = Parameter.create(**child)
@@ -621,8 +655,10 @@ class Parameter(QtCore.QObject):
             if autoIncrementName is True or (autoIncrementName is None and child.opts.get('autoIncrementName', False)):
                 name = self.incrementName(name)
                 child.setName(name)
+            elif existOk:
+                return self.names[name]
             else:
-                raise Exception("Already have child named %s" % str(name))
+                raise ValueError("Already have child named %s" % str(name))
         if isinstance(pos, Parameter):
             pos = self.childs.index(pos)
             
@@ -687,7 +723,7 @@ class Parameter(QtCore.QObject):
 
     def incrementName(self, name):
         ## return an unused name by adding a number to the name given
-        base, num = re.match(r'(.*)(\d*)', name).groups()
+        base, num = re.match(r'([^\d]*)(\d*)', name).groups()
         numLen = len(num)
         if numLen == 0:
             num = 2
@@ -701,14 +737,15 @@ class Parameter(QtCore.QObject):
             num += 1
 
     def __iter__(self):
-        for ch in self.childs:
-            yield ch
+        yield from self.childs
 
     def __getitem__(self, names):
         """Get the value of a child parameter. The name may also be a tuple giving
         the path to a sub-parameter::
         
             value = param[('child', 'grandchild')]
+
+        Raises ValueError if the child value is not set.
         """
         if not isinstance(names, tuple):
             names = (names,)
@@ -736,9 +773,9 @@ class Parameter(QtCore.QObject):
         """
         try:
             param = self.names[names[0]]
-        except KeyError:
-            raise KeyError("Parameter %s has no child named %s" % (self.name(), names[0]))
-        
+        except KeyError as e:
+            raise KeyError(f"Parameter {self.name()} has no child named {names[0]}") from e
+
         if len(names) > 1:
             return param.child(*names[1:])
         else:
@@ -751,24 +788,6 @@ class Parameter(QtCore.QObject):
     def __repr__(self):
         return "<%s '%s' at 0x%x>" % (self.__class__.__name__, self.name(), id(self))
        
-    def __getattr__(self, attr):
-        ## Leaving this undocumented because I might like to remove it in the future..
-        #print type(self), attr
-        warnings.warn(
-            'Use of Parameter.subParam is deprecated and will be removed in 0.13 '
-            'Use Parameter.param(name) instead.',
-            DeprecationWarning, stacklevel=2
-        )          
-        if 'names' not in self.__dict__:
-            raise AttributeError(attr)
-        if attr in self.names:
-            import traceback
-            traceback.print_stack()
-            print("Warning: Use of Parameter.subParam is deprecated. Use Parameter.param(name) instead.")
-            return self.param(attr)
-        else:
-            raise AttributeError(attr)
-       
     def _renameChild(self, child, name):
         ## Only to be called from Parameter.rename
         if name in self.names:
@@ -820,6 +839,7 @@ class Parameter(QtCore.QObject):
         self.emitTreeChanges()
         
         
+    @QtCore.Slot(object, object)
     def treeStateChanged(self, param, changes):
         """
         Called when the state of any sub-parameter has changed. 
@@ -856,5 +876,3 @@ class SignalBlocker(object):
     def __exit__(self, exc_type, exc_value, tb):
         self.exitFn()
     
-    
-    
