@@ -1,5 +1,5 @@
 from ... import functions as fn
-from ...Qt import QtWidgets
+from ...Qt import QtCore, QtWidgets
 from ...SignalProxy import SignalProxy
 from ..ParameterItem import ParameterItem
 from . import BoolParameterItem, SimpleParameter
@@ -66,6 +66,7 @@ class ChecklistParameterItem(GroupParameterItem):
         self.btnGrp.removeButton(child.widget)
 
     def optsChanged(self, param, opts):
+        super().optsChanged(param, opts)
         if 'expanded' in opts:
             for btn in self.metaBtns.values():
                 btn.setVisible(opts['expanded'])
@@ -130,12 +131,13 @@ class RadioParameterItem(BoolParameterItem):
 # Proxy around radio/bool type so the correct item class gets instantiated
 class BoolOrRadioParameter(SimpleParameter):
 
-    def __init__(self, **kargs):
-        if kargs.get('type') == 'bool':
-            self.itemClass = BoolParameterItem
+    @property
+    def itemClass(self):
+        if self.opts.get('type') == 'bool':
+            return BoolParameterItem
         else:
-            self.itemClass = RadioParameterItem
-        super().__init__(**kargs)
+            return RadioParameterItem
+
 
 class ChecklistParameter(GroupParameter):
     """
@@ -174,7 +176,12 @@ class ChecklistParameter(GroupParameter):
             # Also, value calculation will be incorrect until children are added, so make sure to recompute
             self.setValue(value)
 
-        self.valChangingProxy = SignalProxy(self.sigValueChanging, delay=opts.get('delay', 1.0), slot=self._finishChildChanges)
+        self.valChangingProxy = SignalProxy(
+            self.sigValueChanging,
+            delay=opts.get('delay', 1.0),
+            slot=self._finishChildChanges,
+            threadSafe=False,
+        )
 
     def childrenValue(self):
         vals = [self.forward[p.name()] for p in self.children() if p.value()]
@@ -186,6 +193,7 @@ class ChecklistParameter(GroupParameter):
         else:
             return vals
 
+    @QtCore.Slot(object, object)
     def _onChildChanging(self, child, value):
         # When exclusive, ensure only this value is True
         if self.opts['exclusive'] and value:
@@ -194,9 +202,10 @@ class ChecklistParameter(GroupParameter):
             value = self.childrenValue()
         self.sigValueChanging.emit(self, value)
 
+    @QtCore.Slot(object, object)
     def updateLimits(self, _param, limits):
         oldOpts = self.names
-        val = self.opts['value']
+        val = self.opts.get('value', None)
         # Make sure adding and removing children don't cause tree state changes
         self.blockTreeChangeSignal()
         self.clearChildren()
@@ -218,38 +227,59 @@ class ChecklistParameter(GroupParameter):
         self.unblockTreeChangeSignal()
         self.setValue(val)
 
+    @QtCore.Slot(object)
     def _finishChildChanges(self, paramAndValue):
         param, value = paramAndValue
         # Interpret value, fire sigValueChanged
         return self.setValue(value)
 
+    @QtCore.Slot(object, object)
     def optsChanged(self, param, opts):
         if 'exclusive' in opts:
-            # Force set value to ensure updates
-            # self.opts['value'] = self._VALUE_UNSET
             self.updateLimits(None, self.opts.get('limits', []))
         if 'delay' in opts:
             self.valChangingProxy.setDelay(opts['delay'])
 
     def setValue(self, value, blockSignal=None):
         self.targetValue = value
-        exclusive = self.opts['exclusive']
-        # Will emit at the end, so no problem discarding existing changes
-        cmpVals = value if isinstance(value, list) else [value]
-        for ii in range(len(cmpVals)-1, -1, -1):
-            exists = any(fn.eq(cmpVals[ii], lim) for lim in self.reverse[0])
-            if not exists:
-                del cmpVals[ii]
-        names = [self.reverse[1][self.reverse[0].index(val)] for val in cmpVals]
-        if exclusive and len(names) > 1:
-            names = [names[0]]
-        elif exclusive and not len(names) and len(self.forward):
-            # An option is required during exclusivity
-            names = [self.reverse[1][0]]
+        if not isinstance(value, list):
+            value = [value]
+        names, values = self._intersectionWithLimits(value)
+        valueToSet = values
+
+        if self.opts['exclusive']:
+            if len(self.forward):
+                # Exclusive means at least one entry must exist, grab from limits
+                # if they exist
+                names.append(self.reverse[1][0])
+            if len(names) > 1:
+                names = names[:1]
+            if not len(names):
+                valueToSet = None
+            else:
+                valueToSet = self.forward[names[0]]
+
         for chParam in self:
             checked = chParam.name() in names
+            # Will emit at the end, so no problem discarding existing changes
             chParam.setValue(checked, self._onChildChanging)
-        super().setValue(self.childrenValue(), blockSignal)
+        super().setValue(valueToSet, blockSignal)
+
+    def _intersectionWithLimits(self, values: list):
+        """
+        Returns the (names, values) from limits that intersect with ``values``.
+        """
+        allowedNames = []
+        allowedValues = []
+        # Could be replaced by "value in self.reverse[0]" and "reverse[0].index",
+        # but this allows for using pg.eq to cover more diverse value options
+        for val in values:
+            for limitValue, limitName in zip(*self.reverse):
+                if fn.eq(limitValue, val):
+                    allowedNames.append(limitName)
+                    allowedValues.append(val)
+                    break
+        return allowedNames, allowedValues
 
     def setToDefault(self):
         # Since changing values are covered by a proxy, this method must be overridden
