@@ -8,7 +8,8 @@ from .. import functions as fn
 from .. import getConfigOption
 from ..GraphicsScene import GraphicsScene
 from ..Point import Point
-from ..Qt import QT_LIB, QtCore, QtGui, QtWidgets
+from ..Qt import QtCore, QtGui, QtWidgets
+from ..Qt import OpenGLHelpers
 
 __all__ = ['GraphicsView']
 
@@ -101,11 +102,6 @@ class GraphicsView(QtWidgets.QGraphicsView):
         self.sceneObj = GraphicsScene(parent=self)
         self.setScene(self.sceneObj)
         
-        ## Workaround for PySide crash
-        ## This ensures that the scene will outlive the view.
-        if QT_LIB == 'PySide':
-            self.sceneObj._view_ref_workaround = self
-        
         ## by default we set up a central widget with a grid layout.
         ## this can be replaced if needed.
         self.centralWidget = None
@@ -156,16 +152,18 @@ class GraphicsView(QtWidgets.QGraphicsView):
         super(GraphicsView, self).close()
 
     def useOpenGL(self, b=True):
-        if b:
-            HAVE_OPENGL = hasattr(QtWidgets, 'QOpenGLWidget')
-            if not HAVE_OPENGL:
-                raise Exception("Requested to use OpenGL with QGraphicsView, but QOpenGLWidget is not available.")
+        old_vp = self.viewport()
+        new_vp = None
 
-            v = QtWidgets.QOpenGLWidget()
+        if b:
+            if not isinstance(old_vp, OpenGLHelpers.GraphicsViewGLWidget):
+                new_vp = OpenGLHelpers.GraphicsViewGLWidget()
         else:
-            v = QtWidgets.QWidget()
+            if not type(old_vp) is QtWidgets.QWidget:
+                new_vp = QtWidgets.QWidget()
             
-        self.setViewport(v)
+        if new_vp is not None:
+            self.setViewport(new_vp)
             
     def keyPressEvent(self, ev):
         self.scene().keyPressEvent(ev)  ## bypass view, hand event directly to scene
@@ -362,7 +360,7 @@ class GraphicsView(QtWidgets.QGraphicsView):
         super().mouseMoveEvent(ev)
         if not self.mouseEnabled:
             return
-        self.sigSceneMouseMoved.emit(self.mapToScene(lpos))
+        self.sigSceneMouseMoved.emit(self.mapToScene(lpos.toPoint()))
             
         if self.clickAccepted:  ## Ignore event if an item in the scene has already claimed it.
             return
@@ -370,7 +368,7 @@ class GraphicsView(QtWidgets.QGraphicsView):
         if ev.buttons() == QtCore.Qt.MouseButton.RightButton:
             delta = Point(fn.clip_scalar(delta[0], -50, 50), fn.clip_scalar(-delta[1], -50, 50))
             scale = 1.01 ** delta
-            self.scale(scale[0], scale[1], center=self.mapToScene(self.mousePressPos))
+            self.scale(scale[0], scale[1], center=self.mapToScene(self.mousePressPos.toPoint()))
             self.sigDeviceRangeChanged.emit(self, self.range)
 
         elif ev.buttons() in [QtCore.Qt.MouseButton.MiddleButton, QtCore.Qt.MouseButton.LeftButton]:  ## Allow panning by left or mid button.
