@@ -1,6 +1,5 @@
 import numpy as np
 
-from .. import metaarray
 from ..Qt import QtCore, QtGui, QtWidgets
 
 translate = QtCore.QCoreApplication.translate
@@ -95,7 +94,6 @@ class TableWidget(QtWidgets.QTableWidget):
         
           * numpy arrays
           * numpy record arrays
-          * metaarrays
           * list-of-lists  [[1,2,3], [4,5,6]]
           * dict-of-lists  {'x': [1,2,3], 'y': [4,5,6]}
           * list-of-dicts  [{'x': 1, 'y': 4}, {'x': 2, 'y': 5}, ...]
@@ -203,14 +201,6 @@ class TableWidget(QtWidgets.QTableWidget):
             return lambda d: d.__iter__(), None
         elif isinstance(data, dict):
             return lambda d: iter(d.values()), list(map(str, data.keys()))
-        elif (hasattr(data, 'implements') and data.implements('MetaArray')):
-            if data.axisHasColumns(0):
-                header = [str(data.columnName(0, i)) for i in range(data.shape[0])]
-            elif data.axisHasValues(0):
-                header = list(map(str, data.xvals(0)))
-            else:
-                header = None
-            return self.iterFirstAxis, header
         elif isinstance(data, np.ndarray):
             return self.iterFirstAxis, None
         elif isinstance(data, np.void):
@@ -333,32 +323,34 @@ class TableWidget(QtWidgets.QTableWidget):
             s += ('\t'.join(row) + '\n')
         return s
 
+    @QtCore.Slot()
     def copySel(self):
         """Copy selected data to clipboard."""
         QtWidgets.QApplication.clipboard().setText(self.serialize(useSelection=True))
 
+    @QtCore.Slot()
     def copyAll(self):
         """Copy all data to clipboard."""
         QtWidgets.QApplication.clipboard().setText(self.serialize(useSelection=False))
 
+    @QtCore.Slot()
     def saveSel(self):
         """Save selected data to file."""
         self.save(self.serialize(useSelection=True))
 
+    @QtCore.Slot()
     def saveAll(self):
         """Save all data to file."""
         self.save(self.serialize(useSelection=False))
 
     def save(self, data):
-        fileName = QtWidgets.QFileDialog.getSaveFileName(
+        fileName, _ = QtWidgets.QFileDialog.getSaveFileName(
             self,
             f"{translate('TableWidget', 'Save As')}...",
             "",
             f"{translate('TableWidget', 'Tab-separated values')} (*.tsv)"
         )
-        if isinstance(fileName, tuple):
-            fileName = fileName[0]  # Qt4/5 API difference
-        if fileName == '':
+        if not fileName:
             return
         with open(fileName, 'w') as fd:
             fd.write(data)
@@ -373,6 +365,7 @@ class TableWidget(QtWidgets.QTableWidget):
         else:
             super().keyPressEvent(ev)
 
+    @QtCore.Slot(QtWidgets.QTableWidgetItem)
     def handleItemChanged(self, item):
         item.itemChanged()
 
@@ -478,35 +471,6 @@ class TableWidgetItem(QtWidgets.QTableWidgetItem):
         if self.sortMode == 'index' and hasattr(other, 'index'):
             return self.index < other.index
         if self.sortMode == 'value' and hasattr(other, 'value'):
-            return self.value < other.value
+            return bool(self.value < other.value)
         else:
             return self.text() < other.text()
-
-
-if __name__ == '__main__':
-    app = QtWidgets.QApplication([])
-    win = QtWidgets.QMainWindow()
-    t = TableWidget()
-    win.setCentralWidget(t)
-    win.resize(800,600)
-    win.show()
-    
-    ll = [[1,2,3,4,5]] * 20
-    ld = [{'x': 1, 'y': 2, 'z': 3}] * 20
-    dl = {'x': list(range(20)), 'y': list(range(20)), 'z': list(range(20))}
-    
-    a = np.ones((20, 5))
-    ra = np.ones((20,), dtype=[('x', int), ('y', int), ('z', int)])
-    
-    t.setData(ll)
-    
-    ma = metaarray.MetaArray(np.ones((20, 3)), info=[
-        {'values': np.linspace(1, 5, 20)}, 
-        {'cols': [
-            {'name': 'x'},
-            {'name': 'y'},
-            {'name': 'z'},
-        ]}
-    ])
-    t.setData(ma)
-    
