@@ -8,10 +8,12 @@ app = pg.mkQApp()
 def test_nan_image():
     img = np.ones((10,10))
     img[0,0] = np.nan
-    v = pg.image(img)
-    v.imageItem.getHistogram()
+    iv = pg.ImageView()
+    iv.setImage(img)
+    iv.show()
+    iv.getImageItem().getHistogram()
     app.processEvents()
-    v.window().close()
+    iv.window().close()
 
 
 def test_timeslide_snap():
