@@ -13,12 +13,6 @@ def test_isQObjectAlive():
     del o1
     assert not pg.Qt.isQObjectAlive(o2)
 
-@pytest.mark.skipif(
-    pg.Qt.QT_LIB == "PySide2"
-    and tuple(map(int, pg.Qt.PySide2.__version__.split("."))) >= (5, 14) 
-    and tuple(map(int, pg.Qt.PySide2.__version__.split("."))) < (5, 14, 2, 2), 
-    reason="new PySide2 doesn't have loadUi functionality"
-)
 def test_loadUiType():
     path = os.path.dirname(__file__)
     formClass, baseClass = pg.Qt.loadUiType(os.path.join(path, 'uictest.ui'))
