@@ -4,6 +4,8 @@ HistogramLUTWidget test:
 Tests the creation of a HistogramLUTWidget.
 """
 
+
+import itertools
 import numpy as np
 
 import pyqtgraph as pg
@@ -12,7 +14,7 @@ from pyqtgraph.Qt import QtWidgets
 
 def testHistogramLUTWidget():
     pg.mkQApp()
-    
+
     win = QtWidgets.QMainWindow()
     win.show()
 
@@ -33,14 +35,13 @@ def testHistogramLUTWidget():
     l.addWidget(w, 0, 1)
 
     data = pg.gaussianFilter(np.random.normal(size=(256, 256, 3)), (20, 20, 0))
-    for i in range(32):
-        for j in range(32):
-            data[i*8, j*8] += .1
+    for i, j in itertools.product(range(32), range(32)):
+        data[i*8, j*8] += .1
     img = pg.ImageItem(data)
     vb.addItem(img)
     vb.autoRange()
 
     w.setImageItem(img)
-    
+
     QtWidgets.QApplication.processEvents()
     win.close()
